@@ -78,13 +78,14 @@ class BaseClient(object):
 
     def disconnect(self, conf=None, extra_headers=None):
         """Disconnect from the server."""
-        try:
+        if self.connection.connected:
             disconnect = frame.DisconnectFrame(extra_headers=extra_headers)
             result = self.send_frame(disconnect)
-            self.connection.disconnect()
+            try:
+                self.connection.disconnect()
+            except NotConnectedError:
+                pass
             return result
-        except NotConnectedError:
-            pass
         
     def send(self, destination, body=None, transaction=None, extra_headers=None):
         """
